#!/bin/bash
# Start Waltz package manager

# Set variables. 
# APDOCKER_DOMAIN is set in from the systemd .service file
APLINUX_REGISTRY="aplinux-microsoft.azurecr.io${APDOCKER_DOMAIN}"

# Pull a fresh ACR connection config every start
declare ACR_CONFIG=($(../apcommon/refresh_acr_config.py))
if [ $? -ne 0 ]
then
    echo "WARNING: Could not grab the most recent connection configuration for ACR."
fi

if [ -z ${ACR_CONFIG} ]
then
    echo "ERROR: Could not read the cached connection configuration for ACR."
    exit -1
fi

ACR_CLIENT_ID="${ACR_CONFIG[0]}"
ACR_CLIENT_KEY="${ACR_CONFIG[1]}"

if [ -z ${ACR_CLIENT_ID} ] || [ -z ${ACR_CLIENT_KEY} ]
then
    echo "ERROR: Invalid connection configuration cached for ACR."
    exit -1
fi

set -eou pipefail

# Login to aplinux reg
docker login -u ${ACR_CLIENT_ID} -p ${ACR_CLIENT_KEY} ${APLINUX_REGISTRY}

# Pull the image if specified
docker-compose -f ./docker-compose.yml pull

# Get the containers up
# Start etcd first in the background, sometimes health check from waltz
# will fail if etcd has not started up completely.
docker-compose -f ./docker-compose.yml up -d etcd0
docker-compose -f ./docker-compose.yml up --timeout 20
